"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createRendererContainer = createRendererContainer;
exports.trim = trim;
exports.splitWords = splitWords;
exports.create = create;
exports.remove = remove;
exports.addClass = addClass;
exports.removeClass = removeClass;
exports.hasClass = hasClass;
exports.setClass = setClass;
exports.getClass = getClass;
exports.empty = empty;
exports.setTransform = setTransform;
const docStyle = window.document.documentElement.style;

function createRendererContainer(domId) {
  const $wrapper = document.getElementById(domId);

  if ($wrapper) {
    const $container = document.createElement('div');
    $container.style.cssText += `
      position: absolute;
      top: 0;
      z-index:2;
      height: 100%;
      width: 100%;
      pointer-events: none;
    `;
    $container.id = 'l7_canvaslayer';
    $wrapper.appendChild($container);
    return $container;
  }

  return null;
}

function trim(str) {
  return str.trim ? str.trim() : str.replace(/^\s+|\s+$/g, '');
}

function splitWords(str) {
  return trim(str).split(/\s+/);
}

function testProp(props) {
  if (!docStyle) {
    return props[0];
  }

  for (const i in props) {
    if (props[i] && props[i] in docStyle) {
      return props[i];
    }
  }

  return props[0];
}

function create(tagName, className, container) {
  const el = document.createElement(tagName);
  el.className = className || '';

  if (container) {
    container.appendChild(el);
  }

  return el;
}

function remove(el) {
  const parent = el.parentNode;

  if (parent) {
    parent.removeChild(el);
  }
}

function addClass(el, name) {
  if (el.classList !== undefined) {
    const classes = splitWords(name);

    for (let i = 0, len = classes.length; i < len; i++) {
      el.classList.add(classes[i]);
    }
  } else if (!hasClass(el, name)) {
    const className = getClass(el);
    setClass(el, (className ? className + ' ' : '') + name);
  }
}

function removeClass(el, name) {
  if (el.classList !== undefined) {
    el.classList.remove(name);
  } else {
    setClass(el, trim((' ' + getClass(el) + ' ').replace(' ' + name + ' ', ' ')));
  }
}

function hasClass(el, name) {
  if (el.classList !== undefined) {
    return el.classList.contains(name);
  }

  const className = getClass(el);
  return className.length > 0 && new RegExp('(^|\\s)' + name + '(\\s|$)').test(className);
}

function setClass(el, name) {
  if (el instanceof HTMLElement) {
    el.className = name;
  } else {
    el.className.baseVal = name;
  }
}

function getClass(el) {
  if (el instanceof SVGElement) {
    el = el.correspondingElement;
  }

  return el.className.baseVal === undefined ? el.className : el.className.baseVal;
}

function empty(el) {
  while (el.firstChild) {
    el.removeChild(el.firstChild);
  }
}

const transformProp = testProp(['transform', 'WebkitTransform']);

function setTransform(el, value) {
  el.style[transformProp] = value;
}
//# sourceMappingURL=dom.js.map